-- ===========================================================================
-- Automatic Login 1.0 - Plugin for Vendetta Online (all platforms)
-- ===========================================================================
-- Created by Snib in May 2022

-- This plugin can log you in automatically and optionally load your
-- preferred character. This also works after a logout. You can cancel the
-- automation at any time in case you want to manually log into another
-- account or select a different character, or just to read the news.

-- Note that the relogin feature will also reload your entire interface and
-- thus can be used to safely change plugins.

-- =======================================
-- CONFIGURE THE PLUGIN BELOW:
-- =======================================

-- Put your username and password here (enclosed in quotation marks):
local username = ""
local password = ""

-- If you want to automatically enter the game with a particular character,
-- set this variable to that character's slot (1 to 6), otherwise set to 0:
local characterSlot = 1

-- Below you can configure how many seconds the plugin shall wait before
-- performing its actions so you have a chance to cancel or override them.
-- You can configure any positive number to set a delay in seconds.
-- Configuring 0 or a negative number will disable the feature instead.
local loginDelay = 3.001 -- delay at the login screen
local logoutLoginDelay = 3 -- delay after a logout in addition to above
local characterSelectDelay = 5.5 -- delay at the character select screen

-- ===========================================================================
--                   DO NOT CHANGE ANYTHING BELOW THIS LINE
-- ===========================================================================

username = tostring(username) or ""
password = tostring(password) or ""
characterSlot = tonumber(characterSlot) or 0
loginDelay = tonumber(loginDelay) or 0
logoutLoginDelay = tonumber(logoutLoginDelay) or 0
characterSelectDelay = tonumber(characterSelectDelay) or 0

local delay = Timer()
local countdown = Timer()

local loginCancelDialog = iup.dialog {
	iup.hbox {
		iup.stationbutton {
			title = "",
			action = function(self)
				delay:Kill()
				return iup.CLOSE
			end,
			fgcolor = "255 255 255", bgcolor = "255 0 0"
		},
	},
	topmost = "YES", resize = "NO", menubox = "NO"
}

local characterSelectCancelButton = iup.stationbutton {
	title = "Automatic character select in 10s, click to cancel",
	action = function(self)
		delay:Kill()
		self:hide()
	end,
	fgcolor = "255 255 255", bgcolor = "255 0 0"
}

if characterSlot > 0 and characterSelectDelay > 0 then
	iup.Append(CharSelectDialog[1][1], iup.vbox {
		iup.fill {},
		iup.hbox {
			iup.fill {},
			characterSelectCancelButton,
			iup.fill {},
		},
		iup.fill {},
	})
end

local timeRemaining = 0
local timeoutMode = "login"
local timeoutButton = loginCancelDialog[1][1]

local function updateTimeout()
	if timeRemaining > 0 then
		timeoutButton.title = "Automatic " .. timeoutMode .. " in " ..
			string.format("%.1f", timeRemaining) .. "s, click to cancel"
		countdown:SetTimeout(100, updateTimeout)
		timeRemaining = timeRemaining - 0.1
	end
end

local function doLoginCharacter()
	SelectCharacter(characterSlot)
end

local function loginCharacter()
	if characterSlot > 0 then
		timeRemaining = characterSelectDelay
		timeoutMode = "character select"
		timeoutButton = characterSelectCancelButton
		updateTimeout()
		delay:SetTimeout(1000 * characterSelectDelay, doLoginCharacter)
	end
end

local function login()
	if username ~= "" and password ~= "" then
		loginCancelDialog:hide()
		Login(username, password)
	end
end

local function reload()
	timeRemaining = logoutLoginDelay
	timeoutMode = "reload"
	timeoutButton = loginCancelDialog[1][1]
	updateTimeout()
	loginCancelDialog:show()
	delay:SetTimeout(1000 * logoutLoginDelay, ReloadInterface)
end

loginCancelDialog:showxy(tonumber((HUDSize(1)) / 1.9), iup.CENTER)
timeRemaining = loginDelay
timeoutMode = "login"
timeoutButton = loginCancelDialog[1][1]
updateTimeout()
iup.Refresh(loginCancelDialog)
delay:SetTimeout(1000 * loginDelay, login)

RegisterEvent(reload, "PLAYER_LOGGED_OUT")
RegisterEvent(loginCharacter, "UPDATE_CHARACTER_LIST")
